# noinspection RubyClassVariableUsageInspection
class Setting < ActiveRecord::Base
  validates :name, presence: true, uniqueness: true
  validates :value, presence: true

  before_update :reset_setting_variable

  default_scope { order :name }

  DEFAULTS = {
      site_name: 'Personal site',
      title: 'Personal site',
      description: 'Site of your dreams.',
      keywords: 'site, personal site, own site',
      gse_id: '007392588842326689376:3onw-lza4mc',
      google_analytics_id: 'UA-63039804-12'
  }

  def self.init
    DEFAULTS.keys.each { |name| get(name) }
    self
  end

  def self.get(name)
    setting = find_or_initialize_by(name: name)
    setting.update(value: DEFAULTS[name.to_sym]) if setting.new_record?
    setting.value
  end

  def self.site_name
    @@site_name ||= get(:site_name)
  end

  def self.title
    @@title ||= get(:title)
  end

  def self.description
    @@description ||= get(:description)
  end

  def self.keywords
    @@keywords ||= get(:keywords)
  end

  def self.gse_id
    @@gse_id ||= get(:gse_id)
  end

  def self.google_analytics_id
    @@google_analytics_id ||= get(:google_analytics_id)
  end

  private
  def reset_setting_variable
    self.class.class_variable_set "@@#{name}", nil
  end
end
